"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.slashing.v1beta1.slashing_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int
    SIGNING_INFOS_FIELD_NUMBER: builtins.int
    MISSED_BLOCKS_FIELD_NUMBER: builtins.int

    @property
    def params(self) -> cosmos.slashing.v1beta1.slashing_pb2.Params: ...

    @property
    def signing_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SigningInfo]: ...

    @property
    def missed_blocks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorMissedBlocks]: ...

    def __init__(self,
        *,
        params : typing.Optional[cosmos.slashing.v1beta1.slashing_pb2.Params] = ...,
        signing_infos : typing.Optional[typing.Iterable[global___SigningInfo]] = ...,
        missed_blocks : typing.Optional[typing.Iterable[global___ValidatorMissedBlocks]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"missed_blocks",b"missed_blocks",u"params",b"params",u"signing_infos",b"signing_infos"]) -> None: ...
global___GenesisState = GenesisState

class SigningInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_SIGNING_INFO_FIELD_NUMBER: builtins.int
    address: typing.Text = ...

    @property
    def validator_signing_info(self) -> cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo: ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        validator_signing_info : typing.Optional[cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"validator_signing_info",b"validator_signing_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"validator_signing_info",b"validator_signing_info"]) -> None: ...
global___SigningInfo = SigningInfo

class ValidatorMissedBlocks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    MISSED_BLOCKS_FIELD_NUMBER: builtins.int
    address: typing.Text = ...

    @property
    def missed_blocks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MissedBlock]: ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        missed_blocks : typing.Optional[typing.Iterable[global___MissedBlock]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"missed_blocks",b"missed_blocks"]) -> None: ...
global___ValidatorMissedBlocks = ValidatorMissedBlocks

class MissedBlock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INDEX_FIELD_NUMBER: builtins.int
    MISSED_FIELD_NUMBER: builtins.int
    index: builtins.int = ...
    missed: builtins.bool = ...

    def __init__(self,
        *,
        index : builtins.int = ...,
        missed : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"index",b"index",u"missed",b"missed"]) -> None: ...
global___MissedBlock = MissedBlock



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import cosmos.staking.v1beta1.staking_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgCreateValidator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DESCRIPTION_FIELD_NUMBER: builtins.int
    COMMISSION_FIELD_NUMBER: builtins.int
    MIN_SELF_DELEGATION_FIELD_NUMBER: builtins.int
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    PUBKEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    min_self_delegation: typing.Text = ...
    delegator_address: typing.Text = ...
    validator_address: typing.Text = ...

    @property
    def description(self) -> cosmos.staking.v1beta1.staking_pb2.Description: ...

    @property
    def commission(self) -> cosmos.staking.v1beta1.staking_pb2.CommissionRates: ...

    @property
    def pubkey(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def value(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...

    def __init__(self,
        *,
        description : typing.Optional[cosmos.staking.v1beta1.staking_pb2.Description] = ...,
        commission : typing.Optional[cosmos.staking.v1beta1.staking_pb2.CommissionRates] = ...,
        min_self_delegation : typing.Text = ...,
        delegator_address : typing.Text = ...,
        validator_address : typing.Text = ...,
        pubkey : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        value : typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"commission",b"commission",u"description",b"description",u"pubkey",b"pubkey",u"value",b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commission",b"commission",u"delegator_address",b"delegator_address",u"description",b"description",u"min_self_delegation",b"min_self_delegation",u"pubkey",b"pubkey",u"validator_address",b"validator_address",u"value",b"value"]) -> None: ...
global___MsgCreateValidator = MsgCreateValidator

class MsgCreateValidatorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgCreateValidatorResponse = MsgCreateValidatorResponse

class MsgEditValidator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    COMMISSION_RATE_FIELD_NUMBER: builtins.int
    MIN_SELF_DELEGATION_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...
    commission_rate: typing.Text = ...
    min_self_delegation: typing.Text = ...

    @property
    def description(self) -> cosmos.staking.v1beta1.staking_pb2.Description: ...

    def __init__(self,
        *,
        description : typing.Optional[cosmos.staking.v1beta1.staking_pb2.Description] = ...,
        validator_address : typing.Text = ...,
        commission_rate : typing.Text = ...,
        min_self_delegation : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"description",b"description"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commission_rate",b"commission_rate",u"description",b"description",u"min_self_delegation",b"min_self_delegation",u"validator_address",b"validator_address"]) -> None: ...
global___MsgEditValidator = MsgEditValidator

class MsgEditValidatorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgEditValidatorResponse = MsgEditValidatorResponse

class MsgDelegate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    delegator_address: typing.Text = ...
    validator_address: typing.Text = ...

    @property
    def amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...

    def __init__(self,
        *,
        delegator_address : typing.Text = ...,
        validator_address : typing.Text = ...,
        amount : typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"amount",b"amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"delegator_address",b"delegator_address",u"validator_address",b"validator_address"]) -> None: ...
global___MsgDelegate = MsgDelegate

class MsgDelegateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgDelegateResponse = MsgDelegateResponse

class MsgBeginRedelegate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_SRC_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_DST_ADDRESS_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    delegator_address: typing.Text = ...
    validator_src_address: typing.Text = ...
    validator_dst_address: typing.Text = ...

    @property
    def amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...

    def __init__(self,
        *,
        delegator_address : typing.Text = ...,
        validator_src_address : typing.Text = ...,
        validator_dst_address : typing.Text = ...,
        amount : typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"amount",b"amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"delegator_address",b"delegator_address",u"validator_dst_address",b"validator_dst_address",u"validator_src_address",b"validator_src_address"]) -> None: ...
global___MsgBeginRedelegate = MsgBeginRedelegate

class MsgBeginRedelegateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPLETION_TIME_FIELD_NUMBER: builtins.int

    @property
    def completion_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        completion_time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"completion_time",b"completion_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"completion_time",b"completion_time"]) -> None: ...
global___MsgBeginRedelegateResponse = MsgBeginRedelegateResponse

class MsgUndelegate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    delegator_address: typing.Text = ...
    validator_address: typing.Text = ...

    @property
    def amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...

    def __init__(self,
        *,
        delegator_address : typing.Text = ...,
        validator_address : typing.Text = ...,
        amount : typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"amount",b"amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"delegator_address",b"delegator_address",u"validator_address",b"validator_address"]) -> None: ...
global___MsgUndelegate = MsgUndelegate

class MsgUndelegateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPLETION_TIME_FIELD_NUMBER: builtins.int

    @property
    def completion_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        completion_time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"completion_time",b"completion_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"completion_time",b"completion_time"]) -> None: ...
global___MsgUndelegateResponse = MsgUndelegateResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oracle/v1/oracle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='oracle/v1/oracle.proto',
  package='oracle.v1',
  syntax='proto3',
  serialized_options=b'Z,github.com/bandprotocol/chain/x/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16oracle/v1/oracle.proto\x12\toracle.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xc2\x01\n\nDataSource\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x10\n\x08treasury\x18\x05 \x01(\t\x12X\n\x03\x66\x65\x65\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x04\xe8\xa0\x1f\x01\"\x94\x01\n\x0cOracleScript\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x0e\n\x06schema\x18\x05 \x01(\t\x12*\n\x0fsource_code_url\x18\x06 \x01(\tB\x11\xe2\xde\x1f\rSourceCodeURL:\x04\xe8\xa0\x1f\x01\"\x91\x01\n\nRawRequest\x12\x31\n\x0b\x65xternal_id\x18\x01 \x01(\x03\x42\x1c\xe2\xde\x1f\nExternalID\xfa\xde\x1f\nExternalID\x12\x38\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\x03\x42 \xe2\xde\x1f\x0c\x44\x61taSourceID\xfa\xde\x1f\x0c\x44\x61taSourceID\x12\x10\n\x08\x63\x61lldata\x18\x03 \x01(\x0c:\x04\xe8\xa0\x1f\x01\"e\n\tRawReport\x12\x31\n\x0b\x65xternal_id\x18\x01 \x01(\x03\x42\x1c\xe2\xde\x1f\nExternalID\xfa\xde\x1f\nExternalID\x12\x11\n\texit_code\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c:\x04\xe8\xa0\x1f\x01\"\xe5\x02\n\x07Request\x12>\n\x10oracle_script_id\x18\x01 \x01(\x03\x42$\xe2\xde\x1f\x0eOracleScriptID\xfa\xde\x1f\x0eOracleScriptID\x12\x10\n\x08\x63\x61lldata\x18\x02 \x01(\x0c\x12\x1c\n\x14requested_validators\x18\x03 \x03(\t\x12\x11\n\tmin_count\x18\x04 \x01(\x04\x12\x16\n\x0erequest_height\x18\x05 \x01(\x03\x12\x14\n\x0crequest_time\x18\x06 \x01(\x04\x12\x1f\n\tclient_id\x18\x07 \x01(\tB\x0c\xe2\xde\x1f\x08\x43lientID\x12\x31\n\x0craw_requests\x18\x08 \x03(\x0b\x32\x15.oracle.v1.RawRequestB\x04\xc8\xde\x1f\x00\x12:\n\x0bibc_channel\x18\t \x01(\x0b\x32\x15.oracle.v1.IBCChannelB\x0e\xe2\xde\x1f\nIBCChannel\x12\x13\n\x0b\x65xecute_gas\x18\n \x01(\x04:\x04\xe8\xa0\x1f\x01\"m\n\x06Report\x12\x11\n\tvalidator\x18\x01 \x01(\t\x12\x19\n\x11in_before_resolve\x18\x02 \x01(\x08\x12/\n\x0braw_reports\x18\x03 \x03(\x0b\x32\x14.oracle.v1.RawReportB\x04\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"\xd7\x02\n\x17OracleRequestPacketData\x12\x1f\n\tclient_id\x18\x01 \x01(\tB\x0c\xe2\xde\x1f\x08\x43lientID\x12>\n\x10oracle_script_id\x18\x02 \x01(\x03\x42$\xe2\xde\x1f\x0eOracleScriptID\xfa\xde\x1f\x0eOracleScriptID\x12\x10\n\x08\x63\x61lldata\x18\x03 \x01(\x0c\x12\x11\n\task_count\x18\x04 \x01(\x04\x12\x11\n\tmin_count\x18\x05 \x01(\x04\x12^\n\tfee_limit\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x13\n\x0brequest_key\x18\x07 \x01(\t\x12\x13\n\x0bprepare_gas\x18\x08 \x01(\x04\x12\x13\n\x0b\x65xecute_gas\x18\t \x01(\x04:\x04\xe8\xa0\x1f\x01\"Z\n\"OracleRequestPacketAcknowledgement\x12.\n\nrequest_id\x18\x01 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID:\x04\xe8\xa0\x1f\x01\"\xf2\x01\n\x18OracleResponsePacketData\x12\x1f\n\tclient_id\x18\x01 \x01(\tB\x0c\xe2\xde\x1f\x08\x43lientID\x12.\n\nrequest_id\x18\x02 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID\x12\x11\n\tans_count\x18\x03 \x01(\x04\x12\x14\n\x0crequest_time\x18\x04 \x01(\x03\x12\x14\n\x0cresolve_time\x18\x05 \x01(\x03\x12\x30\n\x0eresolve_status\x18\x06 \x01(\x0e\x32\x18.oracle.v1.ResolveStatus\x12\x0e\n\x06result\x18\x07 \x01(\x0c:\x04\xe8\xa0\x1f\x01\"\xd8\x02\n\x06Result\x12\x1f\n\tclient_id\x18\x01 \x01(\tB\x0c\xe2\xde\x1f\x08\x43lientID\x12>\n\x10oracle_script_id\x18\x02 \x01(\x03\x42$\xe2\xde\x1f\x0eOracleScriptID\xfa\xde\x1f\x0eOracleScriptID\x12\x10\n\x08\x63\x61lldata\x18\x03 \x01(\x0c\x12\x11\n\task_count\x18\x04 \x01(\x04\x12\x11\n\tmin_count\x18\x05 \x01(\x04\x12.\n\nrequest_id\x18\x06 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID\x12\x11\n\tans_count\x18\x07 \x01(\x04\x12\x14\n\x0crequest_time\x18\x08 \x01(\x03\x12\x14\n\x0cresolve_time\x18\t \x01(\x03\x12\x30\n\x0eresolve_status\x18\n \x01(\x0e\x32\x18.oracle.v1.ResolveStatus\x12\x0e\n\x06result\x18\x0b \x01(\x0c:\x04\xe8\xa0\x1f\x01\"_\n\x0fValidatorStatus\x12\x11\n\tis_active\x18\x01 \x01(\x08\x12\x33\n\x05since\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01:\x04\xe8\xa0\x1f\x01\"1\n\x0f\x41\x63tiveValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05power\x18\x02 \x01(\x04\"\xb8\x02\n\x06Params\x12\x1d\n\x15max_raw_request_count\x18\x01 \x01(\x04\x12\x15\n\rmax_ask_count\x18\x02 \x01(\x04\x12\x1e\n\x16\x65xpiration_block_count\x18\x03 \x01(\x04\x12\x16\n\x0e\x62\x61se_owasm_gas\x18\x04 \x01(\x04\x12!\n\x19per_validator_request_gas\x18\x05 \x01(\x04\x12\x1a\n\x12sampling_try_count\x18\x06 \x01(\x04\x12 \n\x18oracle_reward_percentage\x18\x07 \x01(\x04\x12!\n\x19inactive_penalty_duration\x18\x08 \x01(\x04\x12\x32\n\x13ibc_request_enabled\x18\t \x01(\x08\x42\x15\xe2\xde\x1f\x11IBCRequestEnabled:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"/\n\x12PendingResolveList\x12\x13\n\x0brequest_ids\x18\x01 \x03(\x03:\x04\xe8\xa0\x1f\x01\"7\n\nIBCChannel\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t:\x04\xe8\xa0\x1f\x01\"C\n\x15ReportersPerValidator\x12\x11\n\tvalidator\x18\x01 \x01(\t\x12\x17\n\treporters\x18\x02 \x03(\tB\x04\xc8\xde\x1f\x00\"\xb0\x01\n\x13RequestVerification\x12\x1d\n\x08\x63hain_id\x18\x01 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\x12\x11\n\tvalidator\x18\x02 \x01(\t\x12.\n\nrequest_id\x18\x03 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID\x12\x31\n\x0b\x65xternal_id\x18\x04 \x01(\x03\x42\x1c\xe2\xde\x1f\nExternalID\xfa\xde\x1f\nExternalID:\x04\xe8\xa0\x1f\x01\"\x83\x01\n\x0bPriceResult\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x12\n\nmultiplier\x18\x02 \x01(\x04\x12\n\n\x02px\x18\x03 \x01(\x04\x12.\n\nrequest_id\x18\x04 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID\x12\x14\n\x0cresolve_time\x18\x05 \x01(\x03*\xfb\x01\n\rResolveStatus\x12<\n\x1fRESOLVE_STATUS_OPEN_UNSPECIFIED\x10\x00\x1a\x17\x8a\x9d \x13RESOLVE_STATUS_OPEN\x12\x36\n\x16RESOLVE_STATUS_SUCCESS\x10\x01\x1a\x1a\x8a\x9d \x16RESOLVE_STATUS_SUCCESS\x12\x36\n\x16RESOLVE_STATUS_FAILURE\x10\x02\x1a\x1a\x8a\x9d \x16RESOLVE_STATUS_FAILURE\x12\x36\n\x16RESOLVE_STATUS_EXPIRED\x10\x03\x1a\x1a\x8a\x9d \x16RESOLVE_STATUS_EXPIRED\x1a\x04\x88\xa3\x1e\x00\x42.Z,github.com/bandprotocol/chain/x/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])

_RESOLVESTATUS = _descriptor.EnumDescriptor(
  name='ResolveStatus',
  full_name='oracle.v1.ResolveStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESOLVE_STATUS_OPEN_UNSPECIFIED', index=0, number=0,
      serialized_options=b'\212\235 \023RESOLVE_STATUS_OPEN',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOLVE_STATUS_SUCCESS', index=1, number=1,
      serialized_options=b'\212\235 \026RESOLVE_STATUS_SUCCESS',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOLVE_STATUS_FAILURE', index=2, number=2,
      serialized_options=b'\212\235 \026RESOLVE_STATUS_FAILURE',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOLVE_STATUS_EXPIRED', index=3, number=3,
      serialized_options=b'\212\235 \026RESOLVE_STATUS_EXPIRED',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\210\243\036\000',
  serialized_start=3203,
  serialized_end=3454,
)
_sym_db.RegisterEnumDescriptor(_RESOLVESTATUS)

ResolveStatus = enum_type_wrapper.EnumTypeWrapper(_RESOLVESTATUS)
RESOLVE_STATUS_OPEN_UNSPECIFIED = 0
RESOLVE_STATUS_SUCCESS = 1
RESOLVE_STATUS_FAILURE = 2
RESOLVE_STATUS_EXPIRED = 3



_DATASOURCE = _descriptor.Descriptor(
  name='DataSource',
  full_name='oracle.v1.DataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.DataSource.owner', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.DataSource.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.DataSource.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='oracle.v1.DataSource.filename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='treasury', full_name='oracle.v1.DataSource.treasury', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='oracle.v1.DataSource.fee', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=346,
)


_ORACLESCRIPT = _descriptor.Descriptor(
  name='OracleScript',
  full_name='oracle.v1.OracleScript',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.OracleScript.owner', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.OracleScript.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.OracleScript.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='oracle.v1.OracleScript.filename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='oracle.v1.OracleScript.schema', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_code_url', full_name='oracle.v1.OracleScript.source_code_url', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\rSourceCodeURL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=497,
)


_RAWREQUEST = _descriptor.Descriptor(
  name='RawRequest',
  full_name='oracle.v1.RawRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_id', full_name='oracle.v1.RawRequest.external_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\nExternalID\372\336\037\nExternalID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_id', full_name='oracle.v1.RawRequest.data_source_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\014DataSourceID\372\336\037\014DataSourceID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.RawRequest.calldata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=645,
)


_RAWREPORT = _descriptor.Descriptor(
  name='RawReport',
  full_name='oracle.v1.RawReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_id', full_name='oracle.v1.RawReport.external_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\nExternalID\372\336\037\nExternalID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='oracle.v1.RawReport.exit_code', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='oracle.v1.RawReport.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=748,
)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='oracle.v1.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.Request.oracle_script_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\016OracleScriptID\372\336\037\016OracleScriptID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.Request.calldata', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_validators', full_name='oracle.v1.Request.requested_validators', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.Request.min_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_height', full_name='oracle.v1.Request.request_height', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_time', full_name='oracle.v1.Request.request_time', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='oracle.v1.Request.client_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\010ClientID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_requests', full_name='oracle.v1.Request.raw_requests', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_channel', full_name='oracle.v1.Request.ibc_channel', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\nIBCChannel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_gas', full_name='oracle.v1.Request.execute_gas', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=1108,
)


_REPORT = _descriptor.Descriptor(
  name='Report',
  full_name='oracle.v1.Report',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.Report.validator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_before_resolve', full_name='oracle.v1.Report.in_before_resolve', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_reports', full_name='oracle.v1.Report.raw_reports', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1219,
)


_ORACLEREQUESTPACKETDATA = _descriptor.Descriptor(
  name='OracleRequestPacketData',
  full_name='oracle.v1.OracleRequestPacketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='oracle.v1.OracleRequestPacketData.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\010ClientID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.OracleRequestPacketData.oracle_script_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\016OracleScriptID\372\336\037\016OracleScriptID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.OracleRequestPacketData.calldata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='oracle.v1.OracleRequestPacketData.ask_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.OracleRequestPacketData.min_count', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_limit', full_name='oracle.v1.OracleRequestPacketData.fee_limit', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_key', full_name='oracle.v1.OracleRequestPacketData.request_key', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prepare_gas', full_name='oracle.v1.OracleRequestPacketData.prepare_gas', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_gas', full_name='oracle.v1.OracleRequestPacketData.execute_gas', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1222,
  serialized_end=1565,
)


_ORACLEREQUESTPACKETACKNOWLEDGEMENT = _descriptor.Descriptor(
  name='OracleRequestPacketAcknowledgement',
  full_name='oracle.v1.OracleRequestPacketAcknowledgement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.OracleRequestPacketAcknowledgement.request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1657,
)


_ORACLERESPONSEPACKETDATA = _descriptor.Descriptor(
  name='OracleResponsePacketData',
  full_name='oracle.v1.OracleResponsePacketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='oracle.v1.OracleResponsePacketData.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\010ClientID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.OracleResponsePacketData.request_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ans_count', full_name='oracle.v1.OracleResponsePacketData.ans_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_time', full_name='oracle.v1.OracleResponsePacketData.request_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='oracle.v1.OracleResponsePacketData.resolve_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_status', full_name='oracle.v1.OracleResponsePacketData.resolve_status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='oracle.v1.OracleResponsePacketData.result', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1660,
  serialized_end=1902,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='oracle.v1.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='oracle.v1.Result.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\010ClientID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.Result.oracle_script_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\016OracleScriptID\372\336\037\016OracleScriptID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.Result.calldata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='oracle.v1.Result.ask_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.Result.min_count', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.Result.request_id', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ans_count', full_name='oracle.v1.Result.ans_count', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_time', full_name='oracle.v1.Result.request_time', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='oracle.v1.Result.resolve_time', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_status', full_name='oracle.v1.Result.resolve_status', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='oracle.v1.Result.result', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1905,
  serialized_end=2249,
)


_VALIDATORSTATUS = _descriptor.Descriptor(
  name='ValidatorStatus',
  full_name='oracle.v1.ValidatorStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_active', full_name='oracle.v1.ValidatorStatus.is_active', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='since', full_name='oracle.v1.ValidatorStatus.since', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\220\337\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2251,
  serialized_end=2346,
)


_ACTIVEVALIDATOR = _descriptor.Descriptor(
  name='ActiveValidator',
  full_name='oracle.v1.ActiveValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='oracle.v1.ActiveValidator.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='power', full_name='oracle.v1.ActiveValidator.power', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2348,
  serialized_end=2397,
)


_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='oracle.v1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_raw_request_count', full_name='oracle.v1.Params.max_raw_request_count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_ask_count', full_name='oracle.v1.Params.max_ask_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_block_count', full_name='oracle.v1.Params.expiration_block_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_owasm_gas', full_name='oracle.v1.Params.base_owasm_gas', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_validator_request_gas', full_name='oracle.v1.Params.per_validator_request_gas', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling_try_count', full_name='oracle.v1.Params.sampling_try_count', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_reward_percentage', full_name='oracle.v1.Params.oracle_reward_percentage', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inactive_penalty_duration', full_name='oracle.v1.Params.inactive_penalty_duration', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_request_enabled', full_name='oracle.v1.Params.ibc_request_enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\021IBCRequestEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001\230\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2400,
  serialized_end=2712,
)


_PENDINGRESOLVELIST = _descriptor.Descriptor(
  name='PendingResolveList',
  full_name='oracle.v1.PendingResolveList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_ids', full_name='oracle.v1.PendingResolveList.request_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2714,
  serialized_end=2761,
)


_IBCCHANNEL = _descriptor.Descriptor(
  name='IBCChannel',
  full_name='oracle.v1.IBCChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='oracle.v1.IBCChannel.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='oracle.v1.IBCChannel.channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2763,
  serialized_end=2818,
)


_REPORTERSPERVALIDATOR = _descriptor.Descriptor(
  name='ReportersPerValidator',
  full_name='oracle.v1.ReportersPerValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.ReportersPerValidator.validator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporters', full_name='oracle.v1.ReportersPerValidator.reporters', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2820,
  serialized_end=2887,
)


_REQUESTVERIFICATION = _descriptor.Descriptor(
  name='RequestVerification',
  full_name='oracle.v1.RequestVerification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='oracle.v1.RequestVerification.chain_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\007ChainID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.RequestVerification.validator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.RequestVerification.request_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_id', full_name='oracle.v1.RequestVerification.external_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\nExternalID\372\336\037\nExternalID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2890,
  serialized_end=3066,
)


_PRICERESULT = _descriptor.Descriptor(
  name='PriceResult',
  full_name='oracle.v1.PriceResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='oracle.v1.PriceResult.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiplier', full_name='oracle.v1.PriceResult.multiplier', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='px', full_name='oracle.v1.PriceResult.px', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.PriceResult.request_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='oracle.v1.PriceResult.resolve_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3069,
  serialized_end=3200,
)

_DATASOURCE.fields_by_name['fee'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_REQUEST.fields_by_name['raw_requests'].message_type = _RAWREQUEST
_REQUEST.fields_by_name['ibc_channel'].message_type = _IBCCHANNEL
_REPORT.fields_by_name['raw_reports'].message_type = _RAWREPORT
_ORACLEREQUESTPACKETDATA.fields_by_name['fee_limit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_ORACLERESPONSEPACKETDATA.fields_by_name['resolve_status'].enum_type = _RESOLVESTATUS
_RESULT.fields_by_name['resolve_status'].enum_type = _RESOLVESTATUS
_VALIDATORSTATUS.fields_by_name['since'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['DataSource'] = _DATASOURCE
DESCRIPTOR.message_types_by_name['OracleScript'] = _ORACLESCRIPT
DESCRIPTOR.message_types_by_name['RawRequest'] = _RAWREQUEST
DESCRIPTOR.message_types_by_name['RawReport'] = _RAWREPORT
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Report'] = _REPORT
DESCRIPTOR.message_types_by_name['OracleRequestPacketData'] = _ORACLEREQUESTPACKETDATA
DESCRIPTOR.message_types_by_name['OracleRequestPacketAcknowledgement'] = _ORACLEREQUESTPACKETACKNOWLEDGEMENT
DESCRIPTOR.message_types_by_name['OracleResponsePacketData'] = _ORACLERESPONSEPACKETDATA
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
DESCRIPTOR.message_types_by_name['ValidatorStatus'] = _VALIDATORSTATUS
DESCRIPTOR.message_types_by_name['ActiveValidator'] = _ACTIVEVALIDATOR
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['PendingResolveList'] = _PENDINGRESOLVELIST
DESCRIPTOR.message_types_by_name['IBCChannel'] = _IBCCHANNEL
DESCRIPTOR.message_types_by_name['ReportersPerValidator'] = _REPORTERSPERVALIDATOR
DESCRIPTOR.message_types_by_name['RequestVerification'] = _REQUESTVERIFICATION
DESCRIPTOR.message_types_by_name['PriceResult'] = _PRICERESULT
DESCRIPTOR.enum_types_by_name['ResolveStatus'] = _RESOLVESTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataSource = _reflection.GeneratedProtocolMessageType('DataSource', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCE,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.DataSource)
  })
_sym_db.RegisterMessage(DataSource)

OracleScript = _reflection.GeneratedProtocolMessageType('OracleScript', (_message.Message,), {
  'DESCRIPTOR' : _ORACLESCRIPT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.OracleScript)
  })
_sym_db.RegisterMessage(OracleScript)

RawRequest = _reflection.GeneratedProtocolMessageType('RawRequest', (_message.Message,), {
  'DESCRIPTOR' : _RAWREQUEST,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.RawRequest)
  })
_sym_db.RegisterMessage(RawRequest)

RawReport = _reflection.GeneratedProtocolMessageType('RawReport', (_message.Message,), {
  'DESCRIPTOR' : _RAWREPORT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.RawReport)
  })
_sym_db.RegisterMessage(RawReport)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.Request)
  })
_sym_db.RegisterMessage(Request)

Report = _reflection.GeneratedProtocolMessageType('Report', (_message.Message,), {
  'DESCRIPTOR' : _REPORT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.Report)
  })
_sym_db.RegisterMessage(Report)

OracleRequestPacketData = _reflection.GeneratedProtocolMessageType('OracleRequestPacketData', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEREQUESTPACKETDATA,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.OracleRequestPacketData)
  })
_sym_db.RegisterMessage(OracleRequestPacketData)

OracleRequestPacketAcknowledgement = _reflection.GeneratedProtocolMessageType('OracleRequestPacketAcknowledgement', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEREQUESTPACKETACKNOWLEDGEMENT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.OracleRequestPacketAcknowledgement)
  })
_sym_db.RegisterMessage(OracleRequestPacketAcknowledgement)

OracleResponsePacketData = _reflection.GeneratedProtocolMessageType('OracleResponsePacketData', (_message.Message,), {
  'DESCRIPTOR' : _ORACLERESPONSEPACKETDATA,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.OracleResponsePacketData)
  })
_sym_db.RegisterMessage(OracleResponsePacketData)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.Result)
  })
_sym_db.RegisterMessage(Result)

ValidatorStatus = _reflection.GeneratedProtocolMessageType('ValidatorStatus', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORSTATUS,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.ValidatorStatus)
  })
_sym_db.RegisterMessage(ValidatorStatus)

ActiveValidator = _reflection.GeneratedProtocolMessageType('ActiveValidator', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVEVALIDATOR,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.ActiveValidator)
  })
_sym_db.RegisterMessage(ActiveValidator)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.Params)
  })
_sym_db.RegisterMessage(Params)

PendingResolveList = _reflection.GeneratedProtocolMessageType('PendingResolveList', (_message.Message,), {
  'DESCRIPTOR' : _PENDINGRESOLVELIST,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.PendingResolveList)
  })
_sym_db.RegisterMessage(PendingResolveList)

IBCChannel = _reflection.GeneratedProtocolMessageType('IBCChannel', (_message.Message,), {
  'DESCRIPTOR' : _IBCCHANNEL,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.IBCChannel)
  })
_sym_db.RegisterMessage(IBCChannel)

ReportersPerValidator = _reflection.GeneratedProtocolMessageType('ReportersPerValidator', (_message.Message,), {
  'DESCRIPTOR' : _REPORTERSPERVALIDATOR,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.ReportersPerValidator)
  })
_sym_db.RegisterMessage(ReportersPerValidator)

RequestVerification = _reflection.GeneratedProtocolMessageType('RequestVerification', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTVERIFICATION,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.RequestVerification)
  })
_sym_db.RegisterMessage(RequestVerification)

PriceResult = _reflection.GeneratedProtocolMessageType('PriceResult', (_message.Message,), {
  'DESCRIPTOR' : _PRICERESULT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.PriceResult)
  })
_sym_db.RegisterMessage(PriceResult)


DESCRIPTOR._options = None
_RESOLVESTATUS._options = None
_RESOLVESTATUS.values_by_name["RESOLVE_STATUS_OPEN_UNSPECIFIED"]._options = None
_RESOLVESTATUS.values_by_name["RESOLVE_STATUS_SUCCESS"]._options = None
_RESOLVESTATUS.values_by_name["RESOLVE_STATUS_FAILURE"]._options = None
_RESOLVESTATUS.values_by_name["RESOLVE_STATUS_EXPIRED"]._options = None
_DATASOURCE.fields_by_name['fee']._options = None
_DATASOURCE._options = None
_ORACLESCRIPT.fields_by_name['source_code_url']._options = None
_ORACLESCRIPT._options = None
_RAWREQUEST.fields_by_name['external_id']._options = None
_RAWREQUEST.fields_by_name['data_source_id']._options = None
_RAWREQUEST._options = None
_RAWREPORT.fields_by_name['external_id']._options = None
_RAWREPORT._options = None
_REQUEST.fields_by_name['oracle_script_id']._options = None
_REQUEST.fields_by_name['client_id']._options = None
_REQUEST.fields_by_name['raw_requests']._options = None
_REQUEST.fields_by_name['ibc_channel']._options = None
_REQUEST._options = None
_REPORT.fields_by_name['raw_reports']._options = None
_REPORT._options = None
_ORACLEREQUESTPACKETDATA.fields_by_name['client_id']._options = None
_ORACLEREQUESTPACKETDATA.fields_by_name['oracle_script_id']._options = None
_ORACLEREQUESTPACKETDATA.fields_by_name['fee_limit']._options = None
_ORACLEREQUESTPACKETDATA._options = None
_ORACLEREQUESTPACKETACKNOWLEDGEMENT.fields_by_name['request_id']._options = None
_ORACLEREQUESTPACKETACKNOWLEDGEMENT._options = None
_ORACLERESPONSEPACKETDATA.fields_by_name['client_id']._options = None
_ORACLERESPONSEPACKETDATA.fields_by_name['request_id']._options = None
_ORACLERESPONSEPACKETDATA._options = None
_RESULT.fields_by_name['client_id']._options = None
_RESULT.fields_by_name['oracle_script_id']._options = None
_RESULT.fields_by_name['request_id']._options = None
_RESULT._options = None
_VALIDATORSTATUS.fields_by_name['since']._options = None
_VALIDATORSTATUS._options = None
_PARAMS.fields_by_name['ibc_request_enabled']._options = None
_PARAMS._options = None
_PENDINGRESOLVELIST._options = None
_IBCCHANNEL._options = None
_REPORTERSPERVALIDATOR.fields_by_name['reporters']._options = None
_REQUESTVERIFICATION.fields_by_name['chain_id']._options = None
_REQUESTVERIFICATION.fields_by_name['request_id']._options = None
_REQUESTVERIFICATION.fields_by_name['external_id']._options = None
_REQUESTVERIFICATION._options = None
_PRICERESULT.fields_by_name['request_id']._options = None
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BitArray(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BITS_FIELD_NUMBER: builtins.int
    ELEMS_FIELD_NUMBER: builtins.int
    bits: builtins.int = ...

    @property
    def elems(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...

    def __init__(self,
        *,
        bits : builtins.int = ...,
        elems : typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"bits",b"bits",u"elems",b"elems"]) -> None: ...
global___BitArray = BitArray



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Params:grpc.UnaryUnaryMultiCallable[
        global___QueryParamsRequest,
        global___QueryParamsResponse] = ...

    ValidatorOutstandingRewards:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorOutstandingRewardsRequest,
        global___QueryValidatorOutstandingRewardsResponse] = ...

    ValidatorCommission:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorCommissionRequest,
        global___QueryValidatorCommissionResponse] = ...

    ValidatorSlashes:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorSlashesRequest,
        global___QueryValidatorSlashesResponse] = ...

    DelegationRewards:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegationRewardsRequest,
        global___QueryDelegationRewardsResponse] = ...

    DelegationTotalRewards:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegationTotalRewardsRequest,
        global___QueryDelegationTotalRewardsResponse] = ...

    DelegatorValidators:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegatorValidatorsRequest,
        global___QueryDelegatorValidatorsResponse] = ...

    DelegatorWithdrawAddress:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegatorWithdrawAddressRequest,
        global___QueryDelegatorWithdrawAddressResponse] = ...

    CommunityPool:grpc.UnaryUnaryMultiCallable[
        global___QueryCommunityPoolRequest,
        global___QueryCommunityPoolResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Params(self,
        request: global___QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryParamsResponse: ...

    @abc.abstractmethod
    def ValidatorOutstandingRewards(self,
        request: global___QueryValidatorOutstandingRewardsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorOutstandingRewardsResponse: ...

    @abc.abstractmethod
    def ValidatorCommission(self,
        request: global___QueryValidatorCommissionRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorCommissionResponse: ...

    @abc.abstractmethod
    def ValidatorSlashes(self,
        request: global___QueryValidatorSlashesRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorSlashesResponse: ...

    @abc.abstractmethod
    def DelegationRewards(self,
        request: global___QueryDelegationRewardsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegationRewardsResponse: ...

    @abc.abstractmethod
    def DelegationTotalRewards(self,
        request: global___QueryDelegationTotalRewardsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegationTotalRewardsResponse: ...

    @abc.abstractmethod
    def DelegatorValidators(self,
        request: global___QueryDelegatorValidatorsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegatorValidatorsResponse: ...

    @abc.abstractmethod
    def DelegatorWithdrawAddress(self,
        request: global___QueryDelegatorWithdrawAddressRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegatorWithdrawAddressResponse: ...

    @abc.abstractmethod
    def CommunityPool(self,
        request: global___QueryCommunityPoolRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryCommunityPoolResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PublicKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ED25519_FIELD_NUMBER: builtins.int
    SECP256K1_FIELD_NUMBER: builtins.int
    ed25519: builtins.bytes = ...
    secp256k1: builtins.bytes = ...

    def __init__(self,
        *,
        ed25519 : builtins.bytes = ...,
        secp256k1 : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"ed25519",b"ed25519",u"secp256k1",b"secp256k1",u"sum",b"sum"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ed25519",b"ed25519",u"secp256k1",b"secp256k1",u"sum",b"sum"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"sum",b"sum"]) -> typing.Optional[typing_extensions.Literal["ed25519","secp256k1"]]: ...
global___PublicKey = PublicKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import google.protobuf.descriptor

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

goproto_enum_prefix: google.protobuf.descriptor.FieldDescriptor = ...

goproto_enum_stringer: google.protobuf.descriptor.FieldDescriptor = ...

enum_stringer: google.protobuf.descriptor.FieldDescriptor = ...

enum_customname: google.protobuf.descriptor.FieldDescriptor = ...

enumdecl: google.protobuf.descriptor.FieldDescriptor = ...

enumvalue_customname: google.protobuf.descriptor.FieldDescriptor = ...

goproto_getters_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_enum_prefix_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_stringer_all: google.protobuf.descriptor.FieldDescriptor = ...

verbose_equal_all: google.protobuf.descriptor.FieldDescriptor = ...

face_all: google.protobuf.descriptor.FieldDescriptor = ...

gostring_all: google.protobuf.descriptor.FieldDescriptor = ...

populate_all: google.protobuf.descriptor.FieldDescriptor = ...

stringer_all: google.protobuf.descriptor.FieldDescriptor = ...

onlyone_all: google.protobuf.descriptor.FieldDescriptor = ...

equal_all: google.protobuf.descriptor.FieldDescriptor = ...

description_all: google.protobuf.descriptor.FieldDescriptor = ...

testgen_all: google.protobuf.descriptor.FieldDescriptor = ...

benchgen_all: google.protobuf.descriptor.FieldDescriptor = ...

marshaler_all: google.protobuf.descriptor.FieldDescriptor = ...

unmarshaler_all: google.protobuf.descriptor.FieldDescriptor = ...

stable_marshaler_all: google.protobuf.descriptor.FieldDescriptor = ...

sizer_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_enum_stringer_all: google.protobuf.descriptor.FieldDescriptor = ...

enum_stringer_all: google.protobuf.descriptor.FieldDescriptor = ...

unsafe_marshaler_all: google.protobuf.descriptor.FieldDescriptor = ...

unsafe_unmarshaler_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_extensions_map_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_unrecognized_all: google.protobuf.descriptor.FieldDescriptor = ...

gogoproto_import: google.protobuf.descriptor.FieldDescriptor = ...

protosizer_all: google.protobuf.descriptor.FieldDescriptor = ...

compare_all: google.protobuf.descriptor.FieldDescriptor = ...

typedecl_all: google.protobuf.descriptor.FieldDescriptor = ...

enumdecl_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_registration: google.protobuf.descriptor.FieldDescriptor = ...

messagename_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_sizecache_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_unkeyed_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_getters: google.protobuf.descriptor.FieldDescriptor = ...

goproto_stringer: google.protobuf.descriptor.FieldDescriptor = ...

verbose_equal: google.protobuf.descriptor.FieldDescriptor = ...

face: google.protobuf.descriptor.FieldDescriptor = ...

gostring: google.protobuf.descriptor.FieldDescriptor = ...

populate: google.protobuf.descriptor.FieldDescriptor = ...

stringer: google.protobuf.descriptor.FieldDescriptor = ...

onlyone: google.protobuf.descriptor.FieldDescriptor = ...

equal: google.protobuf.descriptor.FieldDescriptor = ...

description: google.protobuf.descriptor.FieldDescriptor = ...

testgen: google.protobuf.descriptor.FieldDescriptor = ...

benchgen: google.protobuf.descriptor.FieldDescriptor = ...

marshaler: google.protobuf.descriptor.FieldDescriptor = ...

unmarshaler: google.protobuf.descriptor.FieldDescriptor = ...

stable_marshaler: google.protobuf.descriptor.FieldDescriptor = ...

sizer: google.protobuf.descriptor.FieldDescriptor = ...

unsafe_marshaler: google.protobuf.descriptor.FieldDescriptor = ...

unsafe_unmarshaler: google.protobuf.descriptor.FieldDescriptor = ...

goproto_extensions_map: google.protobuf.descriptor.FieldDescriptor = ...

goproto_unrecognized: google.protobuf.descriptor.FieldDescriptor = ...

protosizer: google.protobuf.descriptor.FieldDescriptor = ...

compare: google.protobuf.descriptor.FieldDescriptor = ...

typedecl: google.protobuf.descriptor.FieldDescriptor = ...

messagename: google.protobuf.descriptor.FieldDescriptor = ...

goproto_sizecache: google.protobuf.descriptor.FieldDescriptor = ...

goproto_unkeyed: google.protobuf.descriptor.FieldDescriptor = ...

nullable: google.protobuf.descriptor.FieldDescriptor = ...

embed: google.protobuf.descriptor.FieldDescriptor = ...

customtype: google.protobuf.descriptor.FieldDescriptor = ...

customname: google.protobuf.descriptor.FieldDescriptor = ...

jsontag: google.protobuf.descriptor.FieldDescriptor = ...

moretags: google.protobuf.descriptor.FieldDescriptor = ...

casttype: google.protobuf.descriptor.FieldDescriptor = ...

castkey: google.protobuf.descriptor.FieldDescriptor = ...

castvalue: google.protobuf.descriptor.FieldDescriptor = ...

stdtime: google.protobuf.descriptor.FieldDescriptor = ...

stdduration: google.protobuf.descriptor.FieldDescriptor = ...

wktpointer: google.protobuf.descriptor.FieldDescriptor = ...

castrepeated: google.protobuf.descriptor.FieldDescriptor = ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.message
import ibc.core.client.v1.client_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgTransfer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SOURCE_PORT_FIELD_NUMBER: builtins.int
    SOURCE_CHANNEL_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    RECEIVER_FIELD_NUMBER: builtins.int
    TIMEOUT_HEIGHT_FIELD_NUMBER: builtins.int
    TIMEOUT_TIMESTAMP_FIELD_NUMBER: builtins.int
    source_port: typing.Text = ...
    source_channel: typing.Text = ...
    sender: typing.Text = ...
    receiver: typing.Text = ...
    timeout_timestamp: builtins.int = ...

    @property
    def token(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...

    @property
    def timeout_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        source_port : typing.Text = ...,
        source_channel : typing.Text = ...,
        token : typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        sender : typing.Text = ...,
        receiver : typing.Text = ...,
        timeout_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        timeout_timestamp : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"timeout_height",b"timeout_height",u"token",b"token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"receiver",b"receiver",u"sender",b"sender",u"source_channel",b"source_channel",u"source_port",b"source_port",u"timeout_height",b"timeout_height",u"timeout_timestamp",b"timeout_timestamp",u"token",b"token"]) -> None: ...
global___MsgTransfer = MsgTransfer

class MsgTransferResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgTransferResponse = MsgTransferResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ParameterChangeProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CHANGES_FIELD_NUMBER: builtins.int
    title: typing.Text = ...
    description: typing.Text = ...

    @property
    def changes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ParamChange]: ...

    def __init__(self,
        *,
        title : typing.Text = ...,
        description : typing.Text = ...,
        changes : typing.Optional[typing.Iterable[global___ParamChange]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"changes",b"changes",u"description",b"description",u"title",b"title"]) -> None: ...
global___ParameterChangeProposal = ParameterChangeProposal

class ParamChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SUBSPACE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    subspace: typing.Text = ...
    key: typing.Text = ...
    value: typing.Text = ...

    def __init__(self,
        *,
        subspace : typing.Text = ...,
        key : typing.Text = ...,
        value : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"subspace",b"subspace",u"value",b"value"]) -> None: ...
global___ParamChange = ParamChange



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import ibc.core.commitment.v1.commitment_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class State(metaclass=_State):
    V = typing.NewType('V', builtins.int)

global___State = State

STATE_UNINITIALIZED_UNSPECIFIED = State.V(0)
STATE_INIT = State.V(1)
STATE_TRYOPEN = State.V(2)
STATE_OPEN = State.V(3)

class _State(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[State.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    STATE_UNINITIALIZED_UNSPECIFIED = State.V(0)
    STATE_INIT = State.V(1)
    STATE_TRYOPEN = State.V(2)
    STATE_OPEN = State.V(3)

class ConnectionEnd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    COUNTERPARTY_FIELD_NUMBER: builtins.int
    DELAY_PERIOD_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    state: global___State.V = ...
    delay_period: builtins.int = ...

    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Version]: ...

    @property
    def counterparty(self) -> global___Counterparty: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        versions : typing.Optional[typing.Iterable[global___Version]] = ...,
        state : global___State.V = ...,
        counterparty : typing.Optional[global___Counterparty] = ...,
        delay_period : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"counterparty",b"counterparty"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"counterparty",b"counterparty",u"delay_period",b"delay_period",u"state",b"state",u"versions",b"versions"]) -> None: ...
global___ConnectionEnd = ConnectionEnd

class IdentifiedConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    COUNTERPARTY_FIELD_NUMBER: builtins.int
    DELAY_PERIOD_FIELD_NUMBER: builtins.int
    id: typing.Text = ...
    client_id: typing.Text = ...
    state: global___State.V = ...
    delay_period: builtins.int = ...

    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Version]: ...

    @property
    def counterparty(self) -> global___Counterparty: ...

    def __init__(self,
        *,
        id : typing.Text = ...,
        client_id : typing.Text = ...,
        versions : typing.Optional[typing.Iterable[global___Version]] = ...,
        state : global___State.V = ...,
        counterparty : typing.Optional[global___Counterparty] = ...,
        delay_period : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"counterparty",b"counterparty"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"counterparty",b"counterparty",u"delay_period",b"delay_period",u"id",b"id",u"state",b"state",u"versions",b"versions"]) -> None: ...
global___IdentifiedConnection = IdentifiedConnection

class Counterparty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    connection_id: typing.Text = ...

    @property
    def prefix(self) -> ibc.core.commitment.v1.commitment_pb2.MerklePrefix: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        connection_id : typing.Text = ...,
        prefix : typing.Optional[ibc.core.commitment.v1.commitment_pb2.MerklePrefix] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"prefix",b"prefix"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"connection_id",b"connection_id",u"prefix",b"prefix"]) -> None: ...
global___Counterparty = Counterparty

class ClientPaths(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATHS_FIELD_NUMBER: builtins.int

    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        paths : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"paths",b"paths"]) -> None: ...
global___ClientPaths = ClientPaths

class ConnectionPaths(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    PATHS_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...

    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        paths : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"paths",b"paths"]) -> None: ...
global___ConnectionPaths = ConnectionPaths

class Version(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IDENTIFIER_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    identifier: typing.Text = ...

    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        identifier : typing.Text = ...,
        features : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"features",b"features",u"identifier",b"identifier"]) -> None: ...
global___Version = Version



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgVerifyInvariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SENDER_FIELD_NUMBER: builtins.int
    INVARIANT_MODULE_NAME_FIELD_NUMBER: builtins.int
    INVARIANT_ROUTE_FIELD_NUMBER: builtins.int
    sender: typing.Text = ...
    invariant_module_name: typing.Text = ...
    invariant_route: typing.Text = ...

    def __init__(self,
        *,
        sender : typing.Text = ...,
        invariant_module_name : typing.Text = ...,
        invariant_route : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"invariant_module_name",b"invariant_module_name",u"invariant_route",b"invariant_route",u"sender",b"sender"]) -> None: ...
global___MsgVerifyInvariant = MsgVerifyInvariant

class MsgVerifyInvariantResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgVerifyInvariantResponse = MsgVerifyInvariantResponse



from pyband.wallet import PrivateKey, PublicKey, Address

TEST_MNEMONIC = "coach pond canoe lake solution empty vacuum term pave toe burst top violin purpose umbrella color disease thrive diamond found track need filter wait"

TEST_ACC_PUBKEY = (
    "bandpub1addwnpepqdg7nrsmuztj2re07svgcz4vuzn3de56nykdwlualepkk05txs5q6mw8s9v"
)
TEST_VAL_PUBKEY = (
    "bandvaloperpub1addwnpepqdg7nrsmuztj2re07svgcz4vuzn3de56nykdwlualepkk05txs5q69gsm29"
)
TEST_CONS_PUBKEY = (
    "bandvalconspub1addwnpepqdg7nrsmuztj2re07svgcz4vuzn3de56nykdwlualepkk05txs5q6r8ytws"
)

TEST_ACC_ADDRESS = "band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c"
TEST_VAL_ADDRESS = "bandvaloper13eznuehmqzd3r84fkxu8wklxl22r2qfm8f05zn"
TEST_CONS_ADDRESS = "bandvalcons13eznuehmqzd3r84fkxu8wklxl22r2qfmn6ugwj"


def test_private_key_from_mnemonic():
    assert (
        PrivateKey.from_mnemonic(TEST_MNEMONIC).to_hex()
        == "2159f40dda9e4c9d8ed9d6f8c353e247a2658993a9d53a94ff17410cd0ea471d"
    )
    assert (
        PrivateKey.from_mnemonic(TEST_MNEMONIC, "m/44'/494'/0'/0/1").to_hex()
        == "987af53f91a09926274e5a2ef86223356112056f61b35a57df345d7b14176bb3"
    )


def test_private_key_generate():
    mnemonic, privkey = PrivateKey.generate("m/44'/494'/0'/0/5")

    assert (
        PrivateKey.from_mnemonic(mnemonic, "m/44'/494'/0'/0/5").to_hex()
        == privkey.to_hex()
    )


def test_private_key_from_hex():
    assert (
        PrivateKey.from_hex(
            "2159f40dda9e4c9d8ed9d6f8c353e247a2658993a9d53a94ff17410cd0ea471d"
        ).to_hex()
        == "2159f40dda9e4c9d8ed9d6f8c353e247a2658993a9d53a94ff17410cd0ea471d"
    )


def test_private_key_to_public_key():
    pub_key = PrivateKey.from_mnemonic(TEST_MNEMONIC).to_public_key()
    assert (
        pub_key.to_hex()
        == "0351e98e1be097250f2ff4188c0aace0a716e69a992cd77f9dfe436b3e8b34280d"
    )


def test_private_key_sign():
    priv_key = PrivateKey.from_mnemonic(TEST_MNEMONIC)
    sig = priv_key.sign(b"test msg")

    assert (
        sig.hex()
        == "42a1e41012155ae2daa9b9a2e038f76463da4662564b4989f236ecb4d97f592c1190d92319363e2d1eb78fb98f0dac30c5e2a850f45bb4c44f1f6203ebe6efbe"
    )


def test_public_key_from_bech32():
    assert (
        PublicKey.from_acc_bech32(TEST_ACC_PUBKEY).to_hex()
        == "0351e98e1be097250f2ff4188c0aace0a716e69a992cd77f9dfe436b3e8b34280d"
    )
    assert (
        PublicKey.from_val_bech32(TEST_VAL_PUBKEY).to_hex()
        == "0351e98e1be097250f2ff4188c0aace0a716e69a992cd77f9dfe436b3e8b34280d"
    )
    assert (
        PublicKey.from_cons_bech32(TEST_CONS_PUBKEY).to_hex()
        == "0351e98e1be097250f2ff4188c0aace0a716e69a992cd77f9dfe436b3e8b34280d"
    )


def test_public_key_to_bech32():
    priv_key = PrivateKey.from_mnemonic(TEST_MNEMONIC)

    assert priv_key.to_public_key().to_acc_bech32() == TEST_ACC_PUBKEY
    assert priv_key.to_public_key().to_val_bech32() == TEST_VAL_PUBKEY
    assert priv_key.to_public_key().to_cons_bech32() == TEST_CONS_PUBKEY


def test_public_key_verify():
    priv_key = PrivateKey.from_mnemonic(TEST_MNEMONIC)
    sig = priv_key.sign(b"test msg")

    pub_key = priv_key.to_public_key()
    assert pub_key.verify(b"test msg", sig) == True
    # Invalid message
    assert pub_key.verify(b"another msg", sig) == False
    # Invalid signature
    assert pub_key.verify(b"test msg", sig[1:]) == False


def test_address_from_bech32():
    assert (
        Address.from_acc_bech32(TEST_ACC_ADDRESS).to_hex()
        == "8e453e66fb009b119ea9b1b8775be6fa9435013b"
    )
    assert (
        Address.from_val_bech32(TEST_VAL_ADDRESS).to_hex()
        == "8e453e66fb009b119ea9b1b8775be6fa9435013b"
    )
    assert (
        Address.from_cons_bech32(TEST_CONS_ADDRESS).to_hex()
        == "8e453e66fb009b119ea9b1b8775be6fa9435013b"
    )


def test_address_to_bech32():
    addr = PrivateKey.from_mnemonic(TEST_MNEMONIC).to_public_key().to_address()

    assert addr.to_acc_bech32() == TEST_ACC_ADDRESS
    assert addr.to_val_bech32() == TEST_VAL_ADDRESS
    assert addr.to_cons_bech32() == TEST_CONS_ADDRESS



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Plan(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    UPGRADED_CLIENT_STATE_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    height: builtins.int = ...
    info: typing.Text = ...

    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    @property
    def upgraded_client_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        height : builtins.int = ...,
        info : typing.Text = ...,
        upgraded_client_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"time",b"time",u"upgraded_client_state",b"upgraded_client_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height",u"info",b"info",u"name",b"name",u"time",b"time",u"upgraded_client_state",b"upgraded_client_state"]) -> None: ...
global___Plan = Plan

class SoftwareUpgradeProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PLAN_FIELD_NUMBER: builtins.int
    title: typing.Text = ...
    description: typing.Text = ...

    @property
    def plan(self) -> global___Plan: ...

    def __init__(self,
        *,
        title : typing.Text = ...,
        description : typing.Text = ...,
        plan : typing.Optional[global___Plan] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"plan",b"plan"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"description",b"description",u"plan",b"plan",u"title",b"title"]) -> None: ...
global___SoftwareUpgradeProposal = SoftwareUpgradeProposal

class CancelSoftwareUpgradeProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    title: typing.Text = ...
    description: typing.Text = ...

    def __init__(self,
        *,
        title : typing.Text = ...,
        description : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"description",b"description",u"title",b"title"]) -> None: ...
global___CancelSoftwareUpgradeProposal = CancelSoftwareUpgradeProposal



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class IdentifiedClientState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_STATE_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...

    @property
    def client_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        client_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"client_state",b"client_state"]) -> None: ...
global___IdentifiedClientState = IdentifiedClientState

class ConsensusStateWithHeight(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    CONSENSUS_STATE_FIELD_NUMBER: builtins.int

    @property
    def height(self) -> global___Height: ...

    @property
    def consensus_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        height : typing.Optional[global___Height] = ...,
        consensus_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"consensus_state",b"consensus_state",u"height",b"height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"consensus_state",b"consensus_state",u"height",b"height"]) -> None: ...
global___ConsensusStateWithHeight = ConsensusStateWithHeight

class ClientConsensusStates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CONSENSUS_STATES_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...

    @property
    def consensus_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConsensusStateWithHeight]: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        consensus_states : typing.Optional[typing.Iterable[global___ConsensusStateWithHeight]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"consensus_states",b"consensus_states"]) -> None: ...
global___ClientConsensusStates = ClientConsensusStates

class ClientUpdateProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    title: typing.Text = ...
    description: typing.Text = ...
    client_id: typing.Text = ...

    @property
    def header(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        title : typing.Text = ...,
        description : typing.Text = ...,
        client_id : typing.Text = ...,
        header : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"description",b"description",u"header",b"header",u"title",b"title"]) -> None: ...
global___ClientUpdateProposal = ClientUpdateProposal

class Height(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REVISION_NUMBER_FIELD_NUMBER: builtins.int
    REVISION_HEIGHT_FIELD_NUMBER: builtins.int
    revision_number: builtins.int = ...
    revision_height: builtins.int = ...

    def __init__(self,
        *,
        revision_number : builtins.int = ...,
        revision_height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"revision_height",b"revision_height",u"revision_number",b"revision_number"]) -> None: ...
global___Height = Height

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ALLOWED_CLIENTS_FIELD_NUMBER: builtins.int

    @property
    def allowed_clients(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        allowed_clients : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"allowed_clients",b"allowed_clients"]) -> None: ...
global___Params = Params



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ChannelOpenInit:grpc.UnaryUnaryMultiCallable[
        global___MsgChannelOpenInit,
        global___MsgChannelOpenInitResponse] = ...

    ChannelOpenTry:grpc.UnaryUnaryMultiCallable[
        global___MsgChannelOpenTry,
        global___MsgChannelOpenTryResponse] = ...

    ChannelOpenAck:grpc.UnaryUnaryMultiCallable[
        global___MsgChannelOpenAck,
        global___MsgChannelOpenAckResponse] = ...

    ChannelOpenConfirm:grpc.UnaryUnaryMultiCallable[
        global___MsgChannelOpenConfirm,
        global___MsgChannelOpenConfirmResponse] = ...

    ChannelCloseInit:grpc.UnaryUnaryMultiCallable[
        global___MsgChannelCloseInit,
        global___MsgChannelCloseInitResponse] = ...

    ChannelCloseConfirm:grpc.UnaryUnaryMultiCallable[
        global___MsgChannelCloseConfirm,
        global___MsgChannelCloseConfirmResponse] = ...

    RecvPacket:grpc.UnaryUnaryMultiCallable[
        global___MsgRecvPacket,
        global___MsgRecvPacketResponse] = ...

    Timeout:grpc.UnaryUnaryMultiCallable[
        global___MsgTimeout,
        global___MsgTimeoutResponse] = ...

    TimeoutOnClose:grpc.UnaryUnaryMultiCallable[
        global___MsgTimeoutOnClose,
        global___MsgTimeoutOnCloseResponse] = ...

    Acknowledgement:grpc.UnaryUnaryMultiCallable[
        global___MsgAcknowledgement,
        global___MsgAcknowledgementResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ChannelOpenInit(self,
        request: global___MsgChannelOpenInit,
        context: grpc.ServicerContext,
    ) -> global___MsgChannelOpenInitResponse: ...

    @abc.abstractmethod
    def ChannelOpenTry(self,
        request: global___MsgChannelOpenTry,
        context: grpc.ServicerContext,
    ) -> global___MsgChannelOpenTryResponse: ...

    @abc.abstractmethod
    def ChannelOpenAck(self,
        request: global___MsgChannelOpenAck,
        context: grpc.ServicerContext,
    ) -> global___MsgChannelOpenAckResponse: ...

    @abc.abstractmethod
    def ChannelOpenConfirm(self,
        request: global___MsgChannelOpenConfirm,
        context: grpc.ServicerContext,
    ) -> global___MsgChannelOpenConfirmResponse: ...

    @abc.abstractmethod
    def ChannelCloseInit(self,
        request: global___MsgChannelCloseInit,
        context: grpc.ServicerContext,
    ) -> global___MsgChannelCloseInitResponse: ...

    @abc.abstractmethod
    def ChannelCloseConfirm(self,
        request: global___MsgChannelCloseConfirm,
        context: grpc.ServicerContext,
    ) -> global___MsgChannelCloseConfirmResponse: ...

    @abc.abstractmethod
    def RecvPacket(self,
        request: global___MsgRecvPacket,
        context: grpc.ServicerContext,
    ) -> global___MsgRecvPacketResponse: ...

    @abc.abstractmethod
    def Timeout(self,
        request: global___MsgTimeout,
        context: grpc.ServicerContext,
    ) -> global___MsgTimeoutResponse: ...

    @abc.abstractmethod
    def TimeoutOnClose(self,
        request: global___MsgTimeoutOnClose,
        context: grpc.ServicerContext,
    ) -> global___MsgTimeoutOnCloseResponse: ...

    @abc.abstractmethod
    def Acknowledgement(self,
        request: global___MsgAcknowledgement,
        context: grpc.ServicerContext,
    ) -> global___MsgAcknowledgementResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Validators:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorsRequest,
        global___QueryValidatorsResponse] = ...

    Validator:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorRequest,
        global___QueryValidatorResponse] = ...

    ValidatorDelegations:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorDelegationsRequest,
        global___QueryValidatorDelegationsResponse] = ...

    ValidatorUnbondingDelegations:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorUnbondingDelegationsRequest,
        global___QueryValidatorUnbondingDelegationsResponse] = ...

    Delegation:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegationRequest,
        global___QueryDelegationResponse] = ...

    UnbondingDelegation:grpc.UnaryUnaryMultiCallable[
        global___QueryUnbondingDelegationRequest,
        global___QueryUnbondingDelegationResponse] = ...

    DelegatorDelegations:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegatorDelegationsRequest,
        global___QueryDelegatorDelegationsResponse] = ...

    DelegatorUnbondingDelegations:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegatorUnbondingDelegationsRequest,
        global___QueryDelegatorUnbondingDelegationsResponse] = ...

    Redelegations:grpc.UnaryUnaryMultiCallable[
        global___QueryRedelegationsRequest,
        global___QueryRedelegationsResponse] = ...

    DelegatorValidators:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegatorValidatorsRequest,
        global___QueryDelegatorValidatorsResponse] = ...

    DelegatorValidator:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegatorValidatorRequest,
        global___QueryDelegatorValidatorResponse] = ...

    HistoricalInfo:grpc.UnaryUnaryMultiCallable[
        global___QueryHistoricalInfoRequest,
        global___QueryHistoricalInfoResponse] = ...

    Pool:grpc.UnaryUnaryMultiCallable[
        global___QueryPoolRequest,
        global___QueryPoolResponse] = ...

    Params:grpc.UnaryUnaryMultiCallable[
        global___QueryParamsRequest,
        global___QueryParamsResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Validators(self,
        request: global___QueryValidatorsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorsResponse: ...

    @abc.abstractmethod
    def Validator(self,
        request: global___QueryValidatorRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorResponse: ...

    @abc.abstractmethod
    def ValidatorDelegations(self,
        request: global___QueryValidatorDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorDelegationsResponse: ...

    @abc.abstractmethod
    def ValidatorUnbondingDelegations(self,
        request: global___QueryValidatorUnbondingDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorUnbondingDelegationsResponse: ...

    @abc.abstractmethod
    def Delegation(self,
        request: global___QueryDelegationRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegationResponse: ...

    @abc.abstractmethod
    def UnbondingDelegation(self,
        request: global___QueryUnbondingDelegationRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryUnbondingDelegationResponse: ...

    @abc.abstractmethod
    def DelegatorDelegations(self,
        request: global___QueryDelegatorDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegatorDelegationsResponse: ...

    @abc.abstractmethod
    def DelegatorUnbondingDelegations(self,
        request: global___QueryDelegatorUnbondingDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegatorUnbondingDelegationsResponse: ...

    @abc.abstractmethod
    def Redelegations(self,
        request: global___QueryRedelegationsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryRedelegationsResponse: ...

    @abc.abstractmethod
    def DelegatorValidators(self,
        request: global___QueryDelegatorValidatorsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegatorValidatorsResponse: ...

    @abc.abstractmethod
    def DelegatorValidator(self,
        request: global___QueryDelegatorValidatorRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegatorValidatorResponse: ...

    @abc.abstractmethod
    def HistoricalInfo(self,
        request: global___QueryHistoricalInfoRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryHistoricalInfoResponse: ...

    @abc.abstractmethod
    def Pool(self,
        request: global___QueryPoolRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPoolResponse: ...

    @abc.abstractmethod
    def Params(self,
        request: global___QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryParamsResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.well_known_types
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Any(google.protobuf.message.Message, google.protobuf.internal.well_known_types.Any):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_URL_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    type_url: typing.Text = ...
    value: builtins.bytes = ...

    def __init__(self,
        *,
        type_url : typing.Text = ...,
        value : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"type_url",b"type_url",u"value",b"value"]) -> None: ...
global___Any = Any



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONSTANT_FEE_FIELD_NUMBER: builtins.int

    @property
    def constant_fee(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...

    def __init__(self,
        *,
        constant_fee : typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"constant_fee",b"constant_fee"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"constant_fee",b"constant_fee"]) -> None: ...
global___GenesisState = GenesisState
